@@ -1,4 +1,4 @@
-__version__ = '0.9'
+__version__ = '0.10'
 
 try:
   from django.conf import settings
@@ -11,7 +11,6 @@ if settings:
   except ImportError:
     from django.conf.urls.defaults import include, url
 
-
   try:
     db_backend = settings.DATABASES['default']['ENGINE']
     if db_backend == 'django.db.backends.postgresql_psycopg2':
@@ -23,7 +22,6 @@ if settings:
   except (ImportError, AttributeError, TypeError):
     __django_database__ = ''
 
-
   try:
     root_project = __import__(settings.ROOT_URLCONF)
     urlpatterns = root_project.urls.urlpatterns
@@ -36,4 +34,4 @@ if settings:
       urlpatterns = None
 
   if urlpatterns:
-    urlpatterns += (url(r'^periscope/', include('periscope.urls')),)
+    urlpatterns.insert(0, url(r'^periscope/', include('periscope.urls')))
