@@ -14,6 +14,9 @@ BAD_WORDS = set(['drop', 'delete', 'update', 'into', 'insert', 'index', 'add', '
              'createdb', 'createuser', 'createrole', 'destroy', 'disconnect', 'exec', 'execute', 'dropdb', 'primary',
              'key', 'rollback', ';', '--'])
 
+MAX_ROWS = 2000
+MAX_SIZE = MAX_ROWS * 500
+
 def login_required(view):
   def decorator(request):
     try:
@@ -39,6 +42,15 @@ def look(request):
       error = 'Potentially harmful keyword found. Blocking command.'
     else:
       cursor = connection.cursor()
+      if __django_database__ == 'postgres':
+        cursor.execute("explain %s" % command)
+        match = re.search("rows=(\d+) width=(\d+)\)$", cursor.fetchall()[0][0])
+        row_count = int(match.group(1))
+        width = int(match.group(2))
+        if row_count > MAX_ROWS:
+          raise Exception("Command blocked because it may be too slow. Estimated at %d rows. Commands must return fewer than %d rows." % (row_count, MAX_ROWS))
+        if row_count * width > MAX_SIZE:
+          raise Exception("Command blocked because it may be too slow. Estimated at %d bytes. Commands must use fewer than %d bytes." % (row_count * width, MAX_SIZE))
       cursor.execute(command)
       data = [OrderedDict(zip([column[0] for column in cursor.description], [unicode(cell) for cell in row])) for row in cursor.fetchall()]
   except Exception as e:
